
===
SQL
===
.. currentmodule:: polars

.. autosummary::
   :toctree: api/


.. py:class:: SQLContext
    :canonical: polars.internals.sql.SQLContext

    Run SQL query against a LazyFrame.

Methods
-------

.. autosummary::
   :toctree: api/

    SQLContext.execute
    SQLContext.register
    SQLContext.query
